# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/session/v1/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/session/v1/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/agentic/session/v1/enum.proto\x12\x1d\x61i.stigmer.agentic.session.v1*Y\n\x10GitWriteBackMode\x12#\n\x1fGIT_WRITE_BACK_MODE_UNSPECIFIED\x10\x00\x12 \n\x1cGIT_WRITE_BACK_BRANCH_AND_PR\x10\x01\x42\xc7\x01\n!com.ai.stigmer.agentic.session.v1B\tEnumProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1d\x41i.Stigmer.Agentic.Session.V1\xca\x02\x1d\x41i\\Stigmer\\Agentic\\Session\\V1\xe2\x02)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Agentic::Session::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.session.v1.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.agentic.session.v1B\tEnumProtoP\001\242\002\004ASAS\252\002\035Ai.Stigmer.Agentic.Session.V1\312\002\035Ai\\Stigmer\\Agentic\\Session\\V1\342\002)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\352\002!Ai::Stigmer::Agentic::Session::V1'
  _globals['_GITWRITEBACKMODE']._serialized_start=75
  _globals['_GITWRITEBACKMODE']._serialized_end=164
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflow.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflow.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/workflow/v1/command.proto\x12\x1e\x61i.stigmer.agentic.workflow.v1\x1a(ai/stigmer/agentic/workflow/v1/api.proto\x1a\'ai/stigmer/agentic/workflow/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xd5\x04\n\x19WorkflowCommandController\x12[\n\x05\x61pply\x12(.ai.stigmer.agentic.workflow.v1.Workflow\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\x12\xaa\x01\n\x06\x63reate\x12(.ai.stigmer.agentic.workflow.v1.Workflow\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\"L\xc2\xb8\x18H\x08\x11\x10\x1e\"\x0cmetadata.org*4unauthorized to create workflow in this organization\x12\x94\x01\n\x06update\x12(.ai.stigmer.agentic.workflow.v1.Workflow\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\"6\xc2\xb8\x18\x32\x08\x04\x10\x32\"\x0bmetadata.id*\x1funauthorized to update workflow\x12\x90\x01\n\x06\x64\x65lete\x12*.ai.stigmer.agentic.workflow.v1.WorkflowId\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\"0\xc2\xb8\x18,\x08\x02\x10\x32\"\x05value*\x1funauthorized to delete workflow\x1a\x04\xa0\xff+2B\xcf\x01\n\"com.ai.stigmer.agentic.workflow.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\x1e\x41i.Stigmer.Agentic.Workflow.V1\xca\x02\x1e\x41i\\Stigmer\\Agentic\\Workflow\\V1\xe2\x02*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\xea\x02\"Ai::Stigmer::Agentic::Workflow::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.agentic.workflow.v1B\014CommandProtoP\001\242\002\004ASAW\252\002\036Ai.Stigmer.Agentic.Workflow.V1\312\002\036Ai\\Stigmer\\Agentic\\Workflow\\V1\342\002*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\352\002\"Ai::Stigmer::Agentic::Workflow::V1'
  _globals['_WORKFLOWCOMMANDCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER']._serialized_options = b'\240\377+2'
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\302\270\030H\010\021\020\036\"\014metadata.org*4unauthorized to create workflow in this organization'
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0302\010\004\0202\"\013metadata.id*\037unauthorized to update workflow'
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030,\010\002\0202\"\005value*\037unauthorized to delete workflow'
  _globals['_WORKFLOWCOMMANDCONTROLLER']._serialized_start=289
  _globals['_WORKFLOWCOMMANDCONTROLLER']._serialized_end=886
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.session.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2
from ai.stigmer.agentic.session.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2


class SessionCommandControllerStub(object):
    """SessionCommandController handles write operations for agent sessions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.apply = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionCommandController/apply',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionCommandController/create',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionCommandController/update',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)
        self.updateSubject = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionCommandController/updateSubject',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.UpdateSessionSubjectRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)
        self.updateSandboxId = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionCommandController/updateSandboxId',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.UpdateSessionSandboxIdRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)


class SessionCommandControllerServicer(object):
    """SessionCommandController handles write operations for agent sessions.
    """

    def apply(self, request, context):
        """Create or update a session.
        The authorization and state-operation are determined depending on whether the session
        is going to be created or updated which is determined as part of the request execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """Create a new session for an agent.
        Requires can_create_session permission in the organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update an existing session (e.g., subject, thread_id, sandbox_id).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateSubject(self, request, context):
        """Set the session subject (server-side field-level update, race-safe).

        Unlike the full update RPC, this atomically modifies only spec.subject
        without touching other fields. This eliminates the lost-update race
        between GenerateSessionSubject and sandbox_manager, which both run in
        parallel during agent execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateSandboxId(self, request, context):
        """Set the session sandbox ID (server-side field-level update, race-safe).

        Unlike the full update RPC, this atomically modifies only spec.sandbox_id
        without touching other fields. This eliminates the lost-update race
        between sandbox_manager and GenerateSessionSubject, which both run in
        parallel during agent execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete a session (also cleans up thread and sandbox).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'apply': grpc.unary_unary_rpc_method_handler(
                    servicer.apply,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
            'updateSubject': grpc.unary_unary_rpc_method_handler(
                    servicer.updateSubject,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.UpdateSessionSubjectRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
            'updateSandboxId': grpc.unary_unary_rpc_method_handler(
                    servicer.updateSandboxId,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.UpdateSessionSandboxIdRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.session.v1.SessionCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.session.v1.SessionCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SessionCommandController(object):
    """SessionCommandController handles write operations for agent sessions.
    """

    @staticmethod
    def apply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionCommandController/apply',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionCommandController/create',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionCommandController/update',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateSubject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionCommandController/updateSubject',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.UpdateSessionSubjectRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateSandboxId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionCommandController/updateSandboxId',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.UpdateSessionSandboxIdRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionCommandController/delete',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TodoItem(_message.Message):
    __slots__ = ("id", "content", "status", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    content: str
    status: _enum_pb2.TodoStatus
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., content: _Optional[str] = ..., status: _Optional[_Union[_enum_pb2.TodoStatus, str]] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...



from ai.stigmer.iam.apikey.v1 import api_pb2 as _api_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiKeys(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.ApiKey]
    def __init__(self, entries: _Optional[_Iterable[_Union[_api_pb2.ApiKey, _Mapping]]] = ...) -> None: ...

class ApiKeyId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class ApiKeyHash(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkspaceWriteBackPhase(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WORKSPACE_WRITE_BACK_PHASE_UNSPECIFIED: _ClassVar[WorkspaceWriteBackPhase]
    WORKSPACE_WRITE_BACK_COMMITTED: _ClassVar[WorkspaceWriteBackPhase]
    WORKSPACE_WRITE_BACK_PUSHED: _ClassVar[WorkspaceWriteBackPhase]
    WORKSPACE_WRITE_BACK_PR_CREATED: _ClassVar[WorkspaceWriteBackPhase]
    WORKSPACE_WRITE_BACK_FAILED: _ClassVar[WorkspaceWriteBackPhase]
WORKSPACE_WRITE_BACK_PHASE_UNSPECIFIED: WorkspaceWriteBackPhase
WORKSPACE_WRITE_BACK_COMMITTED: WorkspaceWriteBackPhase
WORKSPACE_WRITE_BACK_PUSHED: WorkspaceWriteBackPhase
WORKSPACE_WRITE_BACK_PR_CREATED: WorkspaceWriteBackPhase
WORKSPACE_WRITE_BACK_FAILED: WorkspaceWriteBackPhase

class WorkspaceWriteBack(_message.Message):
    __slots__ = ("workspace_entry_name", "branch_name", "base_branch", "commit_sha", "pull_request_url", "pull_request_number", "diff_summary", "phase", "error")
    WORKSPACE_ENTRY_NAME_FIELD_NUMBER: _ClassVar[int]
    BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    BASE_BRANCH_FIELD_NUMBER: _ClassVar[int]
    COMMIT_SHA_FIELD_NUMBER: _ClassVar[int]
    PULL_REQUEST_URL_FIELD_NUMBER: _ClassVar[int]
    PULL_REQUEST_NUMBER_FIELD_NUMBER: _ClassVar[int]
    DIFF_SUMMARY_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_entry_name: str
    branch_name: str
    base_branch: str
    commit_sha: str
    pull_request_url: str
    pull_request_number: int
    diff_summary: str
    phase: WorkspaceWriteBackPhase
    error: str
    def __init__(self, workspace_entry_name: _Optional[str] = ..., branch_name: _Optional[str] = ..., base_branch: _Optional[str] = ..., commit_sha: _Optional[str] = ..., pull_request_url: _Optional[str] = ..., pull_request_number: _Optional[int] = ..., diff_summary: _Optional[str] = ..., phase: _Optional[_Union[WorkspaceWriteBackPhase, str]] = ..., error: _Optional[str] = ...) -> None: ...
